from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Diq:
	"""Diq commands group definition. 2 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("diq", core, parent)

	@property
	def bbMm1(self):
		"""bbMm1 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bbMm1'):
			from .BbMm1 import BbMm1
			self._bbMm1 = BbMm1(self._core, self._base)
		return self._bbMm1

	@property
	def bbMm2(self):
		"""bbMm2 commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_bbMm2'):
			from .BbMm2 import BbMm2
			self._bbMm2 = BbMm2(self._core, self._base)
		return self._bbMm2

	def clone(self) -> 'Diq':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Diq(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 16 total commands, 3 Sub-groups, 13 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	@property
	def add(self):
		"""add commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_add'):
			from .Add import Add
			self._add = Add(self._core, self._base)
		return self._add

	@property
	def change(self):
		"""change commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_change'):
			from .Change import Change
			self._change = Change(self._core, self._base)
		return self._change

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._base)
		return self._execute

	def abort(self) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ABORt \n
		Snippet: driver.source.bb.measurement.power.abort() \n
		Stops the current measurement. \n
		"""
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:ABORt')

	def abort_with_opc(self) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ABORt \n
		Snippet: driver.source.bb.measurement.power.abort_with_opc() \n
		Stops the current measurement. \n
		Same as abort, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce:BB:MEASurement:POWer:ABORt')

	# noinspection PyTypeChecker
	def get_acquisition(self) -> enums.BbMeasPowAcq:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ACQuisition \n
		Snippet: value: enums.BbMeasPowAcq = driver.source.bb.measurement.power.get_acquisition() \n
		Sets the acquisition method. \n
			:return: acquistion: NOMinal| CONTinuous| GATed| MGATed
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:ACQuisition?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowAcq)

	def set_acquisition(self, acquistion: enums.BbMeasPowAcq) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:ACQuisition \n
		Snippet: driver.source.bb.measurement.power.set_acquisition(acquistion = enums.BbMeasPowAcq.CONTinuous) \n
		Sets the acquisition method. \n
			:param acquistion: NOMinal| CONTinuous| GATed| MGATed
		"""
		param = Conversions.enum_scalar_to_str(acquistion, enums.BbMeasPowAcq)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:ACQuisition {param}')

	def delete(self) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DELete \n
		Snippet: driver.source.bb.measurement.power.delete() \n
		Removes the selected measurement from the list. \n
		"""
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:DELete')

	def delete_with_opc(self) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DELete \n
		Snippet: driver.source.bb.measurement.power.delete_with_opc() \n
		Removes the selected measurement from the list. \n
		Same as delete, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce:BB:MEASurement:POWer:DELete')

	def get_duration(self) -> float:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DURation \n
		Snippet: value: float = driver.source.bb.measurement.power.get_duration() \n
		Sets the measurement's time of a single measurement. \n
			:return: duration: float Range: 1E-3 to 5400
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:DURation?')
		return Conversions.str_to_float(response)

	def set_duration(self, duration: float) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:DURation \n
		Snippet: driver.source.bb.measurement.power.set_duration(duration = 1.0) \n
		Sets the measurement's time of a single measurement. \n
			:param duration: float Range: 1E-3 to 5400
		"""
		param = Conversions.decimal_value_to_str(duration)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:DURation {param}')

	# noinspection PyTypeChecker
	def get_gsource(self) -> enums.BbMeasPowGateSour:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:GSOurce \n
		Snippet: value: enums.BbMeasPowGateSour = driver.source.bb.measurement.power.get_gsource() \n
		Determines the marker signal defining the signal part to be evaluated. The available values depend on the selected
		acquisition (method RsSmw.Source.Bb.Measurement.Power.acquisition) . \n
			:return: gate_source: NONE| MARK1| MARK2| MARK3| MGATed NONE Default value for nominal and continuous acquisition. MARK1|MARK2|MARK3 Marker signal as defined in the baseband MGATed Reserved for multi gated acquisition
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:GSOurce?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowGateSour)

	def set_gsource(self, gate_source: enums.BbMeasPowGateSour) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:GSOurce \n
		Snippet: driver.source.bb.measurement.power.set_gsource(gate_source = enums.BbMeasPowGateSour.MARK1) \n
		Determines the marker signal defining the signal part to be evaluated. The available values depend on the selected
		acquisition (method RsSmw.Source.Bb.Measurement.Power.acquisition) . \n
			:param gate_source: NONE| MARK1| MARK2| MARK3| MGATed NONE Default value for nominal and continuous acquisition. MARK1|MARK2|MARK3 Marker signal as defined in the baseband MGATed Reserved for multi gated acquisition
		"""
		param = Conversions.enum_scalar_to_str(gate_source, enums.BbMeasPowGateSour)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:GSOurce {param}')

	def get_index(self) -> int:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:INDex \n
		Snippet: value: int = driver.source.bb.measurement.power.get_index() \n
		Selects the measurement index the subsequent settings apply to, for example changing, starting or removing form the list
		of measurements. \n
			:return: meas_index: integer Range: 1 to dynamic
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:INDex?')
		return Conversions.str_to_int(response)

	def set_index(self, meas_index: int) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:INDex \n
		Snippet: driver.source.bb.measurement.power.set_index(meas_index = 1) \n
		Selects the measurement index the subsequent settings apply to, for example changing, starting or removing form the list
		of measurements. \n
			:param meas_index: integer Range: 1 to dynamic
		"""
		param = Conversions.decimal_value_to_str(meas_index)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:INDex {param}')

	# noinspection PyTypeChecker
	def get_output(self) -> enums.BbMeasPowOutp:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:OUTPut \n
		Snippet: value: enums.BbMeasPowOutp = driver.source.bb.measurement.power.get_output() \n
		Defines the output point the measurement are performed at. \n
			:return: output: RFA| RFB| IQOUT1| IQOUT2| BBMM1| BBMM2
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:OUTPut?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowOutp)

	def set_output(self, output: enums.BbMeasPowOutp) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:OUTPut \n
		Snippet: driver.source.bb.measurement.power.set_output(output = enums.BbMeasPowOutp.BBMM1) \n
		Defines the output point the measurement are performed at. \n
			:param output: RFA| RFB| IQOUT1| IQOUT2| BBMM1| BBMM2
		"""
		param = Conversions.enum_scalar_to_str(output, enums.BbMeasPowOutp)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:OUTPut {param}')

	def get_peak(self) -> List[float]:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:PEAK \n
		Snippet: value: List[float] = driver.source.bb.measurement.power.get_peak() \n
		Queries the peak power of the baseband signal at the measurement point determined with the command method RsSmw.Source.Bb.
		Measurement.Power.output. \n
			:return: peak_power: Peak_SubMes#1,Peak_SubMes#2,... Returns the peak power of the measured signal or if a multi-gated acquisition is used, a string of measured values with one value per performed submeasurement Range: -145 to 30
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:BB:MEASurement:POWer:PEAK?')
		return response

	def get_progress(self) -> float:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:PROGress \n
		Snippet: value: float = driver.source.bb.measurement.power.get_progress() \n
		Queries the status of the initiated measurement. The query returns a value that indicates the task progress in percent. \n
			:return: progress: float Range: 0 to 100
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:PROGress?')
		return Conversions.str_to_float(response)

	# noinspection PyTypeChecker
	def get_rmode(self) -> enums.BlerTrigMode:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RMODe \n
		Snippet: value: enums.BlerTrigMode = driver.source.bb.measurement.power.get_rmode() \n
		Determines whether a single or a continuous measurement is executed. \n
			:return: run_mode: SINGle| AUTO
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:RMODe?')
		return Conversions.str_to_scalar_enum(response, enums.BlerTrigMode)

	def set_rmode(self, run_mode: enums.BlerTrigMode) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RMODe \n
		Snippet: driver.source.bb.measurement.power.set_rmode(run_mode = enums.BlerTrigMode.AUTO) \n
		Determines whether a single or a continuous measurement is executed. \n
			:param run_mode: SINGle| AUTO
		"""
		param = Conversions.enum_scalar_to_str(run_mode, enums.BlerTrigMode)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:RMODe {param}')

	def get_rms(self) -> List[float]:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RMS \n
		Snippet: value: List[float] = driver.source.bb.measurement.power.get_rms() \n
		Queries the RMS power of the baseband signal at the measurement point determined with the command method RsSmw.Source.Bb.
		Measurement.Power.output. \n
			:return: rms_power: Power_SubMes#1,Level_SubMes#2,... Returns the power of the measured signal or if a multi-gated acquisition is used, a string of measured values with one value per performed submeasurement Range: -145 to 30
		"""
		response = self._core.io.query_bin_or_ascii_float_list('SOURce:BB:MEASurement:POWer:RMS?')
		return response

	def get_rstate(self) -> bool:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:RSTate \n
		Snippet: value: bool = driver.source.bb.measurement.power.get_rstate() \n
		Queries the state (running/stopped) of the current measurement. \n
			:return: run_state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:RSTate?')
		return Conversions.str_to_bool(response)

	# noinspection PyTypeChecker
	def get_source(self) -> enums.BbMeasPowSour:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:SOURce \n
		Snippet: value: enums.BbMeasPowSour = driver.source.bb.measurement.power.get_source() \n
		Defines the measurement signal source. \n
			:return: source: BBA| BBB| BBC| BBD| BBINA| BBINB| FADINPA| FADINPB| FADINPC| FADINPD| FADOUTA| FADOUTB| FADOUTC| FADOUTD| AWGNA| AWGNB| AWGNC| AWGND| STREAMA| STREAMB| STREAMC| STREAMD
		"""
		response = self._core.io.query_str('SOURce:BB:MEASurement:POWer:SOURce?')
		return Conversions.str_to_scalar_enum(response, enums.BbMeasPowSour)

	def set_source(self, source: enums.BbMeasPowSour) -> None:
		"""SCPI: [SOURce]:BB:MEASurement:POWer:SOURce \n
		Snippet: driver.source.bb.measurement.power.set_source(source = enums.BbMeasPowSour.AWGNA) \n
		Defines the measurement signal source. \n
			:param source: BBA| BBB| BBC| BBD| BBINA| BBINB| FADINPA| FADINPB| FADINPC| FADINPD| FADOUTA| FADOUTB| FADOUTC| FADOUTD| AWGNA| AWGNB| AWGNC| AWGND| STREAMA| STREAMB| STREAMC| STREAMD
		"""
		param = Conversions.enum_scalar_to_str(source, enums.BbMeasPowSour)
		self._core.io.write(f'SOURce:BB:MEASurement:POWer:SOURce {param}')

	def clone(self) -> 'Power':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Power(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dpcch:
	"""Dpcch commands group definition. 60 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dpcch", core, parent)

	@property
	def ccode(self):
		"""ccode commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ccode'):
			from .Ccode import Ccode
			self._ccode = Ccode(self._core, self._base)
		return self._ccode

	@property
	def fbi(self):
		"""fbi commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_fbi'):
			from .Fbi import Fbi
			self._fbi = Fbi(self._core, self._base)
		return self._fbi

	@property
	def hs(self):
		"""hs commands group. 20 Sub-classes, 0 commands."""
		if not hasattr(self, '_hs'):
			from .Hs import Hs
			self._hs = Hs(self._core, self._base)
		return self._hs

	@property
	def power(self):
		"""power commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def sformat(self):
		"""sformat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sformat'):
			from .Sformat import Sformat
			self._sformat = Sformat(self._core, self._base)
		return self._sformat

	@property
	def tfci(self):
		"""tfci commands group. 1 Sub-classes, 1 commands."""
		if not hasattr(self, '_tfci'):
			from .Tfci import Tfci
			self._tfci = Tfci(self._core, self._base)
		return self._tfci

	@property
	def toffset(self):
		"""toffset commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_toffset'):
			from .Toffset import Toffset
			self._toffset = Toffset(self._core, self._base)
		return self._toffset

	@property
	def tpc(self):
		"""tpc commands group. 5 Sub-classes, 0 commands."""
		if not hasattr(self, '_tpc'):
			from .Tpc import Tpc
			self._tpc = Tpc(self._core, self._base)
		return self._tpc

	def clone(self) -> 'Dpcch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dpcch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pusch:
	"""Pusch commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pusch", core, parent)

	# noinspection PyTypeChecker
	def get_fh_mode(self) -> enums.UlFreqHopMode:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:FHMode \n
		Snippet: value: enums.UlFreqHopMode = driver.source.bb.v5G.uplink.pusch.get_fh_mode() \n
		No command help available \n
			:return: freq_hopping_mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUSCh:FHMode?')
		return Conversions.str_to_scalar_enum(response, enums.UlFreqHopMode)

	def set_fh_mode(self, freq_hopping_mode: enums.UlFreqHopMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:FHMode \n
		Snippet: driver.source.bb.v5G.uplink.pusch.set_fh_mode(freq_hopping_mode = enums.UlFreqHopMode.INTer) \n
		No command help available \n
			:param freq_hopping_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(freq_hopping_mode, enums.UlFreqHopMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUSCh:FHMode {param}')

	def get_fh_offset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:FHOFfset \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pusch.get_fh_offset() \n
		No command help available \n
			:return: fhopp_offset: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUSCh:FHOFfset?')
		return Conversions.str_to_int(response)

	def set_fh_offset(self, fhopp_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:FHOFfset \n
		Snippet: driver.source.bb.v5G.uplink.pusch.set_fh_offset(fhopp_offset = 1) \n
		No command help available \n
			:param fhopp_offset: No help available
		"""
		param = Conversions.decimal_value_to_str(fhopp_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUSCh:FHOFfset {param}')

	def get_nhoffset(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:NHOFfset \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pusch.get_nhoffset() \n
		No command help available \n
			:return: nb_hopping_offset: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUSCh:NHOFfset?')
		return Conversions.str_to_int(response)

	def set_nhoffset(self, nb_hopping_offset: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:NHOFfset \n
		Snippet: driver.source.bb.v5G.uplink.pusch.set_nhoffset(nb_hopping_offset = 1) \n
		No command help available \n
			:param nb_hopping_offset: No help available
		"""
		param = Conversions.decimal_value_to_str(nb_hopping_offset)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUSCh:NHOFfset {param}')

	def get_nhopping(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:NHOPping \n
		Snippet: value: bool = driver.source.bb.v5G.uplink.pusch.get_nhopping() \n
		No command help available \n
			:return: nb_hopping: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUSCh:NHOPping?')
		return Conversions.str_to_bool(response)

	def set_nhopping(self, nb_hopping: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:NHOPping \n
		Snippet: driver.source.bb.v5G.uplink.pusch.set_nhopping(nb_hopping = False) \n
		No command help available \n
			:param nb_hopping: No help available
		"""
		param = Conversions.bool_to_str(nb_hopping)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUSCh:NHOPping {param}')

	def get_nosm(self) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:NOSM \n
		Snippet: value: int = driver.source.bb.v5G.uplink.pusch.get_nosm() \n
		No command help available \n
			:return: sub_band_count: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:UL:PUSCh:NOSM?')
		return Conversions.str_to_int(response)

	def set_nosm(self, sub_band_count: int) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:UL:PUSCh:NOSM \n
		Snippet: driver.source.bb.v5G.uplink.pusch.set_nosm(sub_band_count = 1) \n
		No command help available \n
			:param sub_band_count: No help available
		"""
		param = Conversions.decimal_value_to_str(sub_band_count)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:UL:PUSCh:NOSM {param}')



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Insert:
	"""Insert commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("insert", core, parent)

	def set(self, vehicle=repcap.Vehicle.Default, obscuredArea=repcap.ObscuredArea.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA<CH>:INSert \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.area.insert.set(vehicle = repcap.Vehicle.Default, obscuredArea = repcap.ObscuredArea.Default) \n
		Appends, insertes or deletes an obscured zone. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param obscuredArea: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Area')"""
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		obscuredArea_cmd_val = self._base.get_repcap_cmd_value(obscuredArea, repcap.ObscuredArea)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA{obscuredArea_cmd_val}:INSert')

	def set_with_opc(self, vehicle=repcap.Vehicle.Default, obscuredArea=repcap.ObscuredArea.Default) -> None:
		vehicle_cmd_val = self._base.get_repcap_cmd_value(vehicle, repcap.Vehicle)
		obscuredArea_cmd_val = self._base.get_repcap_cmd_value(obscuredArea, repcap.ObscuredArea)
		"""SCPI: [SOURce<HW>]:BB:GNSS:RECeiver:[V<ST>]:ENVironment:FULL:AREA<CH>:INSert \n
		Snippet: driver.source.bb.gnss.receiver.v.environment.full.area.insert.set_with_opc(vehicle = repcap.Vehicle.Default, obscuredArea = repcap.ObscuredArea.Default) \n
		Appends, insertes or deletes an obscured zone. \n
		Same as set, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
			:param vehicle: optional repeated capability selector. Default value: Nr1 (settable in the interface 'V')
			:param obscuredArea: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Area')"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:BB:GNSS:RECeiver:V{vehicle_cmd_val}:ENVironment:FULL:AREA{obscuredArea_cmd_val}:INSert')



"""Single argument definition for a list argument."""

from .ArgSingle import ArgSingle
from .ArgStringComposer import compose_cmd_string_from_single_args


class ArgSingleList(object):
	"""Contains methods for composing cmd string for the list of single arguments.
	Used in methods with 1+ set or query arguments.
	The instance does not have a fixed args list, you can use the instance method compose_cmd_string with different arguments."""

	def __init__(self):
		self.args = None

	def compose_cmd_string(self, arg1: ArgSingle, arg2: ArgSingle = None, arg3: ArgSingle = None, arg4: ArgSingle = None, arg5: ArgSingle = None, arg6: ArgSingle = None, arg7: ArgSingle = None, arg8: ArgSingle = None, arg9: ArgSingle = None):
		"""Composes the string cmd argument from the arguments list.
		Same treatment as in the ArgStructList.compose_cmd_string().
		The difference is in handling the value of the argument."""
		self.args = dict()

		ix = 0
		for arg in [arg1, arg2, arg3, arg4, arg5, arg6, arg7, arg8, arg9]:
			if arg:
				self.args[ix] = arg
				ix += 1

		return compose_cmd_string_from_single_args(self.args)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class View:
	"""View commands group definition. 5 total commands, 0 Sub-groups, 5 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("view", core, parent)

	def get_bis(self) -> bool:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:BIS \n
		Snippet: value: bool = driver.source.bb.v5G.downlink.view.get_bis() \n
		No command help available \n
			:return: block_info: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:DL:VIEW:BIS?')
		return Conversions.str_to_bool(response)

	def set_bis(self, block_info: bool) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:BIS \n
		Snippet: driver.source.bb.v5G.downlink.view.set_bis(block_info = False) \n
		No command help available \n
			:param block_info: No help available
		"""
		param = Conversions.bool_to_str(block_info)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:VIEW:BIS {param}')

	# noinspection PyTypeChecker
	def get_cindex(self) -> enums.CcIndex:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:CINDex \n
		Snippet: value: enums.CcIndex = driver.source.bb.v5G.downlink.view.get_cindex() \n
		No command help available \n
			:return: dl_tp_cell_idx: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:DL:VIEW:CINDex?')
		return Conversions.str_to_scalar_enum(response, enums.CcIndex)

	def set_cindex(self, dl_tp_cell_idx: enums.CcIndex) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:CINDex \n
		Snippet: driver.source.bb.v5G.downlink.view.set_cindex(dl_tp_cell_idx = enums.CcIndex.PC) \n
		No command help available \n
			:param dl_tp_cell_idx: No help available
		"""
		param = Conversions.enum_scalar_to_str(dl_tp_cell_idx, enums.CcIndex)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:VIEW:CINDex {param}')

	def get_fsts(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:FSTS \n
		Snippet: value: float = driver.source.bb.v5G.downlink.view.get_fsts() \n
		No command help available \n
			:return: fsts: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:DL:VIEW:FSTS?')
		return Conversions.str_to_float(response)

	def set_fsts(self, fsts: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:FSTS \n
		Snippet: driver.source.bb.v5G.downlink.view.set_fsts(fsts = 1.0) \n
		No command help available \n
			:param fsts: No help available
		"""
		param = Conversions.decimal_value_to_str(fsts)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:VIEW:FSTS {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.ViewMode:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:MODE \n
		Snippet: value: enums.ViewMode = driver.source.bb.v5G.downlink.view.get_mode() \n
		No command help available \n
			:return: mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:DL:VIEW:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.ViewMode)

	def set_mode(self, mode: enums.ViewMode) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:MODE \n
		Snippet: driver.source.bb.v5G.downlink.view.set_mode(mode = enums.ViewMode.PRB) \n
		No command help available \n
			:param mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.ViewMode)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:VIEW:MODE {param}')

	def get_viss(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:VISS \n
		Snippet: value: float = driver.source.bb.v5G.downlink.view.get_viss() \n
		No command help available \n
			:return: viss: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:V5G:DL:VIEW:VISS?')
		return Conversions.str_to_float(response)

	def set_viss(self, viss: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:VIEW:VISS \n
		Snippet: driver.source.bb.v5G.downlink.view.set_viss(viss = 1.0) \n
		No command help available \n
			:param viss: No help available
		"""
		param = Conversions.decimal_value_to_str(viss)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:VIEW:VISS {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Frequency:
	"""Frequency commands group definition. 10 total commands, 2 Sub-groups, 7 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("frequency", core, parent)

	@property
	def execute(self):
		"""execute commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_execute'):
			from .Execute import Execute
			self._execute = Execute(self._core, self._base)
		return self._execute

	@property
	def step(self):
		"""step commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_step'):
			from .Step import Step
			self._step = Step(self._core, self._base)
		return self._step

	def get_dwell(self) -> float:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:DWELl \n
		Snippet: value: float = driver.source.lfOutput.sweep.frequency.get_dwell() \n
		Sets the dwell time for each frequency step of the sweep. \n
			:return: dwell: float Range: 0.001 to 100, Unit: s
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:DWELl?')
		return Conversions.str_to_float(response)

	def set_dwell(self, dwell: float) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:DWELl \n
		Snippet: driver.source.lfOutput.sweep.frequency.set_dwell(dwell = 1.0) \n
		Sets the dwell time for each frequency step of the sweep. \n
			:param dwell: float Range: 0.001 to 100, Unit: s
		"""
		param = Conversions.decimal_value_to_str(dwell)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput:SWEep:FREQuency:DWELl {param}')

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.AutoManStep:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:MODE \n
		Snippet: value: enums.AutoManStep = driver.source.lfOutput.sweep.frequency.get_mode() \n
		Sets the cycle mode of the LF sweep. \n
			:return: mode: AUTO| MANual| STEP AUTO Performs a complete sweep cycle from the start to the end value when a trigger event occurs. The dwell time determines the time period until the signal switches to the next step. MANual Performs a single sweep step when a manual trigger event occurs. The trigger system is not active. To trigger each frequency step of the sweep individually, use the command method RsSmw.Source.LfOutput.Frequency.manual. STEP Each trigger command triggers one sweep step only. The frequency increases by the value set with the coammnds: method RsSmw.Source.LfOutput.State.set (linear spacing) LFOutput:STEP:LOGarithmic(logarithmic spacing)
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.AutoManStep)

	def set_mode(self, mode: enums.AutoManStep) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:MODE \n
		Snippet: driver.source.lfOutput.sweep.frequency.set_mode(mode = enums.AutoManStep.AUTO) \n
		Sets the cycle mode of the LF sweep. \n
			:param mode: AUTO| MANual| STEP AUTO Performs a complete sweep cycle from the start to the end value when a trigger event occurs. The dwell time determines the time period until the signal switches to the next step. MANual Performs a single sweep step when a manual trigger event occurs. The trigger system is not active. To trigger each frequency step of the sweep individually, use the command method RsSmw.Source.LfOutput.Frequency.manual. STEP Each trigger command triggers one sweep step only. The frequency increases by the value set with the coammnds: method RsSmw.Source.LfOutput.State.set (linear spacing) LFOutput:STEP:LOGarithmic(logarithmic spacing)
		"""
		param = Conversions.enum_scalar_to_str(mode, enums.AutoManStep)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput:SWEep:FREQuency:MODE {param}')

	def get_points(self) -> int:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:POINts \n
		Snippet: value: int = driver.source.lfOutput.sweep.frequency.get_points() \n
		Sets the number of steps in an LF sweep. For information on how the value is calculated and the interdependency with
		other parameters, see 'Correlating Parameters in Sweep Mode' \n
			:return: points: integer Range: 2 to POINts
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:POINts?')
		return Conversions.str_to_int(response)

	def set_points(self, points: int) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:POINts \n
		Snippet: driver.source.lfOutput.sweep.frequency.set_points(points = 1) \n
		Sets the number of steps in an LF sweep. For information on how the value is calculated and the interdependency with
		other parameters, see 'Correlating Parameters in Sweep Mode' \n
			:param points: integer Range: 2 to POINts
		"""
		param = Conversions.decimal_value_to_str(points)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput:SWEep:FREQuency:POINts {param}')

	def get_retrace(self) -> bool:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:RETRace \n
		Snippet: value: bool = driver.source.lfOutput.sweep.frequency.get_retrace() \n
		Activates that the signal changes to the start frequency value while it is waiting for the next trigger event. You can
		enable this feature, when you are working with sawtooth shapes in sweep mode 'Single' or 'External Single'. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:RETRace?')
		return Conversions.str_to_bool(response)

	def set_retrace(self, state: bool) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:RETRace \n
		Snippet: driver.source.lfOutput.sweep.frequency.set_retrace(state = False) \n
		Activates that the signal changes to the start frequency value while it is waiting for the next trigger event. You can
		enable this feature, when you are working with sawtooth shapes in sweep mode 'Single' or 'External Single'. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput:SWEep:FREQuency:RETRace {param}')

	def get_running(self) -> bool:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:RUNNing \n
		Snippet: value: bool = driver.source.lfOutput.sweep.frequency.get_running() \n
		Queries the current status of the LF frequency sweep mode. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:RUNNing?')
		return Conversions.str_to_bool(response)

	# noinspection PyTypeChecker
	def get_shape(self) -> enums.SweCyclMode:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:SHAPe \n
		Snippet: value: enums.SweCyclMode = driver.source.lfOutput.sweep.frequency.get_shape() \n
		Sets the cycle mode for a sweep sequence (shape) . \n
			:return: shape: SAWTooth| TRIangle
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:SHAPe?')
		return Conversions.str_to_scalar_enum(response, enums.SweCyclMode)

	def set_shape(self, shape: enums.SweCyclMode) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:SHAPe \n
		Snippet: driver.source.lfOutput.sweep.frequency.set_shape(shape = enums.SweCyclMode.SAWTooth) \n
		Sets the cycle mode for a sweep sequence (shape) . \n
			:param shape: SAWTooth| TRIangle
		"""
		param = Conversions.enum_scalar_to_str(shape, enums.SweCyclMode)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput:SWEep:FREQuency:SHAPe {param}')

	# noinspection PyTypeChecker
	def get_spacing(self) -> enums.Spacing:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:SPACing \n
		Snippet: value: enums.Spacing = driver.source.lfOutput.sweep.frequency.get_spacing() \n
		Selects linear or logarithmic sweep spacing. \n
			:return: spacing: LINear| LOGarithmic
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:LFOutput:SWEep:FREQuency:SPACing?')
		return Conversions.str_to_scalar_enum(response, enums.Spacing)

	def set_spacing(self, spacing: enums.Spacing) -> None:
		"""SCPI: [SOURce<HW>]:LFOutput:SWEep:[FREQuency]:SPACing \n
		Snippet: driver.source.lfOutput.sweep.frequency.set_spacing(spacing = enums.Spacing.LINear) \n
		Selects linear or logarithmic sweep spacing. \n
			:param spacing: LINear| LOGarithmic
		"""
		param = Conversions.enum_scalar_to_str(spacing, enums.Spacing)
		self._core.io.write(f'SOURce<HwInstance>:LFOutput:SWEep:FREQuency:SPACing {param}')

	def clone(self) -> 'Frequency':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Frequency(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal.RepeatedCapability import RepeatedCapability
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Set:
	"""Set commands group definition. 8 total commands, 8 Sub-groups, 0 group commands
	Repeated Capability: ModCodSet, default value after init: ModCodSet.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("set", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_modCodSet_get', 'repcap_modCodSet_set', repcap.ModCodSet.Nr1)

	def repcap_modCodSet_set(self, enum_value: repcap.ModCodSet) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to ModCodSet.Default
		Default value after init: ModCodSet.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_modCodSet_get(self) -> repcap.ModCodSet:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def adfl(self):
		"""adfl commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_adfl'):
			from .Adfl import Adfl
			self._adfl = Adfl(self._core, self._base)
		return self._adfl

	@property
	def ctype(self):
		"""ctype commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ctype'):
			from .Ctype import Ctype
			self._ctype = Ctype(self._core, self._base)
		return self._ctype

	@property
	def dfl(self):
		"""dfl commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_dfl'):
			from .Dfl import Dfl
			self._dfl = Dfl(self._core, self._base)
		return self._dfl

	@property
	def frames(self):
		"""frames commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_frames'):
			from .Frames import Frames
			self._frames = Frames(self._core, self._base)
		return self._frames

	@property
	def mcod(self):
		"""mcod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_mcod'):
			from .Mcod import Mcod
			self._mcod = Mcod(self._core, self._base)
		return self._mcod

	@property
	def pcod(self):
		"""pcod commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_pcod'):
			from .Pcod import Pcod
			self._pcod = Pcod(self._core, self._base)
		return self._pcod

	@property
	def pstate(self):
		"""pstate commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pstate'):
			from .Pstate import Pstate
			self._pstate = Pstate(self._core, self._base)
		return self._pstate

	@property
	def sfactor(self):
		"""sfactor commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_sfactor'):
			from .Sfactor import Sfactor
			self._sfactor = Sfactor(self._core, self._base)
		return self._sfactor

	def clone(self) -> 'Set':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Set(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class StStream:
	"""StStream commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("stStream", core, parent)

	def set(self, st_stream: int, frameBlock=repcap.FrameBlock.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:STSTream \n
		Snippet: driver.source.bb.wlnn.fblock.stStream.set(st_stream = 1, frameBlock = repcap.FrameBlock.Default) \n
		Sets the number of the space time streams. This value depends on the number of spatial streams defined with command
		method RsSmw.Source.Bb.Wlnn.Fblock.Sstream.set. Changing the number of the Spatial Streams immediately changes the value
		of the Space Time Streams to the same value. \n
			:param st_stream: integer Range: 1 to dynamic
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')"""
		param = Conversions.decimal_value_to_str(st_stream)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:STSTream {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:STSTream \n
		Snippet: value: int = driver.source.bb.wlnn.fblock.stStream.get(frameBlock = repcap.FrameBlock.Default) \n
		Sets the number of the space time streams. This value depends on the number of spatial streams defined with command
		method RsSmw.Source.Bb.Wlnn.Fblock.Sstream.set. Changing the number of the Spatial Streams immediately changes the value
		of the Space Time Streams to the same value. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:return: st_stream: integer Range: 1 to dynamic"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:STSTream?')
		return Conversions.str_to_int(response)



from typing import List

from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def get_catalog(self) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:USER:HOTime:FILE:CATalog \n
		Snippet: value: List[str] = driver.source.bb.esequencer.user.hoTime.file.get_catalog() \n
		Queries the available hopping list files. As response, you get a string containing the hopping list files *.
		ps_hop, separated by commas. To set the default directory, use command method RsSmw.MassMemory.currentDirectory. \n
			:return: catalog: string
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ESEQuencer:USER:HOTime:FILE:CATalog?')
		return Conversions.str_to_str_list(response)



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from .......Internal.RepeatedCapability import RepeatedCapability
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tshift:
	"""Tshift commands group definition. 1 total commands, 0 Sub-groups, 1 group commands
	Repeated Capability: Index, default value after init: Index.Nr1"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tshift", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_index_get', 'repcap_index_set', repcap.Index.Nr1)

	def repcap_index_set(self, enum_value: repcap.Index) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to Index.Default
		Default value after init: Index.Nr1"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_index_get(self) -> repcap.Index:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	def set(self, tshift: float, frameBlock=repcap.FrameBlock.Default, index=repcap.Index.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:SMAPping:TSHift<ST> \n
		Snippet: driver.source.bb.wlnn.fblock.smapping.tshift.set(tshift = 1.0, frameBlock = repcap.FrameBlock.Default, index = repcap.Index.Default) \n
		Sets the spatial mapping time shift. This value is relevant for spatial mapping mode direct and spatial expansion only. \n
			:param tshift: float Range: -32000 ns to 32000 ns
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tshift')"""
		param = Conversions.decimal_value_to_str(tshift)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		index_cmd_val = self._base.get_repcap_cmd_value(index, repcap.Index)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:SMAPping:TSHift{index_cmd_val} {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, index=repcap.Index.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:SMAPping:TSHift<ST> \n
		Snippet: value: float = driver.source.bb.wlnn.fblock.smapping.tshift.get(frameBlock = repcap.FrameBlock.Default, index = repcap.Index.Default) \n
		Sets the spatial mapping time shift. This value is relevant for spatial mapping mode direct and spatial expansion only. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param index: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tshift')
			:return: tshift: float Range: -32000 ns to 32000 ns"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		index_cmd_val = self._base.get_repcap_cmd_value(index, repcap.Index)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:SMAPping:TSHift{index_cmd_val}?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Tshift':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tshift(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Edch:
	"""Edch commands group definition. 5 total commands, 4 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("edch", core, parent)

	@property
	def repeat(self):
		"""repeat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_repeat'):
			from .Repeat import Repeat
			self._repeat = Repeat(self._core, self._base)
		return self._repeat

	@property
	def row(self):
		"""row commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_row'):
			from .Row import Row
			self._row = Row(self._core, self._base)
		return self._row

	@property
	def rowCount(self):
		"""rowCount commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rowCount'):
			from .RowCount import RowCount
			self._rowCount = RowCount(self._core, self._base)
		return self._rowCount

	@property
	def ttiedch(self):
		"""ttiedch commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ttiedch'):
			from .Ttiedch import Ttiedch
			self._ttiedch = Ttiedch(self._core, self._base)
		return self._ttiedch

	def clone(self) -> 'Edch':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Edch(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Stair:
	"""Stair commands group definition. 4 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("stair", core, parent)

	@property
	def dwell(self):
		"""dwell commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_dwell'):
			from .Dwell import Dwell
			self._dwell = Dwell(self._core, self._base)
		return self._dwell

	@property
	def step(self):
		"""step commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_step'):
			from .Step import Step
			self._step = Step(self._core, self._base)
		return self._step

	def clone(self) -> 'Stair':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Stair(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...Internal.Core import Core
from ...Internal.CommandsGroup import CommandsGroup
from ...Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Psave:
	"""Psave commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("psave", core, parent)

	def get_holdoff(self) -> int:
		"""SCPI: DISPlay:PSAVe:HOLDoff \n
		Snippet: value: int = driver.display.psave.get_holdoff() \n
		Sets the wait time for the screen saver mode of the display. \n
			:return: holdoff_time_min: integer Range: 1 to 60, Unit: minute
		"""
		response = self._core.io.query_str('DISPlay:PSAVe:HOLDoff?')
		return Conversions.str_to_int(response)

	def set_holdoff(self, holdoff_time_min: int) -> None:
		"""SCPI: DISPlay:PSAVe:HOLDoff \n
		Snippet: driver.display.psave.set_holdoff(holdoff_time_min = 1) \n
		Sets the wait time for the screen saver mode of the display. \n
			:param holdoff_time_min: integer Range: 1 to 60, Unit: minute
		"""
		param = Conversions.decimal_value_to_str(holdoff_time_min)
		self._core.io.write(f'DISPlay:PSAVe:HOLDoff {param}')

	def get_state(self) -> bool:
		"""SCPI: DISPlay:PSAVe:[STATe] \n
		Snippet: value: bool = driver.display.psave.get_state() \n
		Activates the screen saver mode of the display. We recommend that you use this mode to protect the display, if you
		operate the instrument in remote control. To define the wait time, use the command method RsSmw.Display.Psave.holdoff. \n
			:return: state: 0| 1| OFF| ON
		"""
		response = self._core.io.query_str('DISPlay:PSAVe:STATe?')
		return Conversions.str_to_bool(response)

	def set_state(self, state: bool) -> None:
		"""SCPI: DISPlay:PSAVe:[STATe] \n
		Snippet: driver.display.psave.set_state(state = False) \n
		Activates the screen saver mode of the display. We recommend that you use this mode to protect the display, if you
		operate the instrument in remote control. To define the wait time, use the command method RsSmw.Display.Psave.holdoff. \n
			:param state: 0| 1| OFF| ON
		"""
		param = Conversions.bool_to_str(state)
		self._core.io.write(f'DISPlay:PSAVe:STATe {param}')



from .....Internal.Core import Core
from .....Internal.CommandsGroup import CommandsGroup
from .....Internal import Conversions
from ..... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Set:
	"""Set commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("set", core, parent)

	def set(self, ecount: int, errorCount=repcap.ErrorCount.Default) -> None:
		"""SCPI: DIAGnostic:INFO:ECOunt<CH>:SET \n
		Snippet: driver.diagnostic.info.ecount.set.set(ecount = 1, errorCount = repcap.ErrorCount.Default) \n
		No command help available \n
			:param ecount: No help available
			:param errorCount: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ecount')"""
		param = Conversions.decimal_value_to_str(ecount)
		errorCount_cmd_val = self._base.get_repcap_cmd_value(errorCount, repcap.ErrorCount)
		self._core.io.write(f'DIAGnostic:INFO:ECOunt{errorCount_cmd_val}:SET {param}')



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions
from ...... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Rtci:
	"""Rtci commands group definition. 24 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("rtci", core, parent)

	@property
	def wave(self):
		"""wave commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_wave'):
			from .Wave import Wave
			self._wave = Wave(self._core, self._base)
		return self._wave

	@property
	def wlist(self):
		"""wlist commands group. 2 Sub-classes, 0 commands."""
		if not hasattr(self, '_wlist'):
			from .Wlist import Wlist
			self._wlist = Wlist(self._core, self._base)
		return self._wlist

	@property
	def sequencer(self):
		"""sequencer commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_sequencer'):
			from .Sequencer import Sequencer
			self._sequencer = Sequencer(self._core, self._base)
		return self._sequencer

	# noinspection PyTypeChecker
	def get_pdw_format(self) -> enums.ExtSeqPdwVariant:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:PDWFormat \n
		Snippet: value: enums.ExtSeqPdwVariant = driver.source.bb.esequencer.rtci.get_pdw_format() \n
		Selects the PDW format. \n
			:return: format_py: BASic| EXPert
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:ESEQuencer:RTCI:PDWFormat?')
		return Conversions.str_to_scalar_enum(response, enums.ExtSeqPdwVariant)

	def set_pdw_format(self, format_py: enums.ExtSeqPdwVariant) -> None:
		"""SCPI: [SOURce<HW>]:BB:ESEQuencer:RTCI:PDWFormat \n
		Snippet: driver.source.bb.esequencer.rtci.set_pdw_format(format_py = enums.ExtSeqPdwVariant.BASic) \n
		Selects the PDW format. \n
			:param format_py: BASic| EXPert
		"""
		param = Conversions.enum_scalar_to_str(format_py, enums.ExtSeqPdwVariant)
		self._core.io.write(f'SOURce<HwInstance>:BB:ESEQuencer:RTCI:PDWFormat {param}')

	def clone(self) -> 'Rtci':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Rtci(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Sweep:
	"""Sweep commands group definition. 27 total commands, 3 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("sweep", core, parent)

	@property
	def combined(self):
		"""combined commands group. 1 Sub-classes, 5 commands."""
		if not hasattr(self, '_combined'):
			from .Combined import Combined
			self._combined = Combined(self._core, self._base)
		return self._combined

	@property
	def power(self):
		"""power commands group. 3 Sub-classes, 7 commands."""
		if not hasattr(self, '_power'):
			from .Power import Power
			self._power = Power(self._core, self._base)
		return self._power

	@property
	def frequency(self):
		"""frequency commands group. 2 Sub-classes, 7 commands."""
		if not hasattr(self, '_frequency'):
			from .Frequency import Frequency
			self._frequency = Frequency(self._core, self._base)
		return self._frequency

	def reset_all(self) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:RESet:[ALL] \n
		Snippet: driver.source.sweep.reset_all() \n
		Resets all active sweeps to the starting point. \n
		"""
		self._core.io.write(f'SOURce<HwInstance>:SWEep:RESet:ALL')

	def reset_all_with_opc(self) -> None:
		"""SCPI: [SOURce<HW>]:SWEep:RESet:[ALL] \n
		Snippet: driver.source.sweep.reset_all_with_opc() \n
		Resets all active sweeps to the starting point. \n
		Same as reset_all, but waits for the operation to complete before continuing further. Use the RsSmw.utilities.opc_timeout_set() to set the timeout value. \n
		"""
		self._core.io.write_with_opc(f'SOURce<HwInstance>:SWEep:RESet:ALL')

	def clone(self) -> 'Sweep':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Sweep(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal.Types import DataType
from .........Internal.StructBase import StructBase
from .........Internal.ArgStruct import ArgStruct
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pattern:
	"""Pattern commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pattern", core, parent)

	# noinspection PyTypeChecker
	class PatternStruct(StructBase):
		"""Structure for setting input parameters. Fields: \n
			- Pattern: List[str]: numeric
			- Bitcount: int: integer Range: 1 to 64"""
		__meta_args_list = [
			ArgStruct('Pattern', DataType.RawStringList, None, False, True, 1),
			ArgStruct.scalar_int('Bitcount')]

		def __init__(self):
			StructBase.__init__(self, self)
			self.Pattern: List[str] = None
			self.Bitcount: int = None

	def set(self, structure: PatternStruct, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:DATA:PATTern \n
		Snippet: driver.source.bb.c2K.bstation.cgroup.coffset.data.pattern.set(value = [PROPERTY_STRUCT_NAME](), baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Sets the bit pattern for the PATTern selection. The first parameter determines the bit pattern (choice of hexadecimal,
		octal or binary notation) , the second specifies the number of bits to use. For the traffic channels, this value is
		specific for the selected radio configuration. \n
			:param structure: for set value, see the help for PatternStruct structure arguments.
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		self._core.io.write_struct(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:DATA:PATTern', structure)

	def get(self, baseStation=repcap.BaseStation.Default, groupNull=repcap.GroupNull.Default, offset=repcap.Offset.Default) -> PatternStruct:
		"""SCPI: [SOURce<HW>]:BB:C2K:BSTation<ST>:CGRoup<DI0>:COFFset<CH>:DATA:PATTern \n
		Snippet: value: PatternStruct = driver.source.bb.c2K.bstation.cgroup.coffset.data.pattern.get(baseStation = repcap.BaseStation.Default, groupNull = repcap.GroupNull.Default, offset = repcap.Offset.Default) \n
		Sets the bit pattern for the PATTern selection. The first parameter determines the bit pattern (choice of hexadecimal,
		octal or binary notation) , the second specifies the number of bits to use. For the traffic channels, this value is
		specific for the selected radio configuration. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param groupNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cgroup')
			:param offset: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Coffset')
			:return: structure: for return value, see the help for PatternStruct structure arguments."""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		groupNull_cmd_val = self._base.get_repcap_cmd_value(groupNull, repcap.GroupNull)
		offset_cmd_val = self._base.get_repcap_cmd_value(offset, repcap.Offset)
		return self._core.io.query_struct(f'SOURce<HwInstance>:BB:C2K:BSTation{baseStation_cmd_val}:CGRoup{groupNull_cmd_val}:COFFset{offset_cmd_val}:DATA:PATTern?', self.__class__.PatternStruct())



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from .... import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Clock:
	"""Clock commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("clock", core, parent)

	# noinspection PyTypeChecker
	def get_rate(self) -> enums.BbClock:
		"""SCPI: [SOURce<HW>]:FSIMulator:CLOCk:RATE \n
		Snippet: value: enums.BbClock = driver.source.fsimulator.clock.get_rate() \n
		Queries the clock rate the fading simulator is using for the signal processing. \n
			:return: cloc_rate: CR200| CR100| CR050| CR025 | CR250| CR125| CR062| CR500| CR1G CR200 = 200 MHz, CR100 = 100 MHz, CR050 = 50 MHz, CR025 = 25 MHz CR250 = 250 MHz, CR125 = 125 MHz, CR062 = 62.5 MHz, CR500 = 500 MHz, CR1G = 1GHz The value depends on the selected 'System Configuration' and influences the bandwidth of the generated signal. *) CR200M (R&S SMW-B10) /CR250M (R&S SMW-B9)
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:CLOCk:RATE?')
		return Conversions.str_to_scalar_enum(response, enums.BbClock)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Cbarred:
	"""Cbarred commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("cbarred", core, parent)

	def set(self, ssp_bch_cell_barre: enums.CellBarring, cellNull=repcap.CellNull.Nr0, ssPbchNull=repcap.SsPbchNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:SSPBch<ST0>:MIB:CBARred \n
		Snippet: driver.source.bb.nr5G.node.cell.sspbch.mib.cbarred.set(ssp_bch_cell_barre = enums.CellBarring.BARR, cellNull = repcap.CellNull.Nr0, ssPbchNull = repcap.SsPbchNull.Default) \n
		Cell barring is system information that indicates if UEs can camp on the particular cell NBAR or not BARR. \n
			:param ssp_bch_cell_barre: BARR| NBAR
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param ssPbchNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')"""
		param = Conversions.enum_scalar_to_str(ssp_bch_cell_barre, enums.CellBarring)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		ssPbchNull_cmd_val = self._base.get_repcap_cmd_value(ssPbchNull, repcap.SsPbchNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{ssPbchNull_cmd_val}:MIB:CBARred {param}')

	# noinspection PyTypeChecker
	def get(self, cellNull=repcap.CellNull.Nr0, ssPbchNull=repcap.SsPbchNull.Default) -> enums.CellBarring:
		"""SCPI: [SOURce<HW>]:BB:NR5G:NODE:CELL<CH0>:SSPBch<ST0>:MIB:CBARred \n
		Snippet: value: enums.CellBarring = driver.source.bb.nr5G.node.cell.sspbch.mib.cbarred.get(cellNull = repcap.CellNull.Nr0, ssPbchNull = repcap.SsPbchNull.Default) \n
		Cell barring is system information that indicates if UEs can camp on the particular cell NBAR or not BARR. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0
			:param ssPbchNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Sspbch')
			:return: ssp_bch_cell_barre: BARR| NBAR"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		ssPbchNull_cmd_val = self._base.get_repcap_cmd_value(ssPbchNull, repcap.SsPbchNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:NR5G:NODE:CELL{cellNull_cmd_val}:SSPBch{ssPbchNull_cmd_val}:MIB:CBARred?')
		return Conversions.str_to_scalar_enum(response, enums.CellBarring)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tx:
	"""Tx commands group definition. 116 total commands, 29 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tx", core, parent)

	@property
	def ac(self):
		"""ac commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ac'):
			from .Ac import Ac
			self._ac = Ac(self._core, self._base)
		return self._ac

	@property
	def ad(self):
		"""ad commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ad'):
			from .Ad import Ad
			self._ad = Ad(self._core, self._base)
		return self._ad

	@property
	def ae(self):
		"""ae commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ae'):
			from .Ae import Ae
			self._ae = Ae(self._core, self._base)
		return self._ae

	@property
	def af(self):
		"""af commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_af'):
			from .Af import Af
			self._af = Af(self._core, self._base)
		return self._af

	@property
	def ag(self):
		"""ag commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ag'):
			from .Ag import Ag
			self._ag = Ag(self._core, self._base)
		return self._ag

	@property
	def ah(self):
		"""ah commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ah'):
			from .Ah import Ah
			self._ah = Ah(self._core, self._base)
		return self._ah

	@property
	def bc(self):
		"""bc commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bc'):
			from .Bc import Bc
			self._bc = Bc(self._core, self._base)
		return self._bc

	@property
	def bd(self):
		"""bd commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bd'):
			from .Bd import Bd
			self._bd = Bd(self._core, self._base)
		return self._bd

	@property
	def be(self):
		"""be commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_be'):
			from .Be import Be
			self._be = Be(self._core, self._base)
		return self._be

	@property
	def bf(self):
		"""bf commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bf'):
			from .Bf import Bf
			self._bf = Bf(self._core, self._base)
		return self._bf

	@property
	def bg(self):
		"""bg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bg'):
			from .Bg import Bg
			self._bg = Bg(self._core, self._base)
		return self._bg

	@property
	def bh(self):
		"""bh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_bh'):
			from .Bh import Bh
			self._bh = Bh(self._core, self._base)
		return self._bh

	@property
	def cd(self):
		"""cd commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_cd'):
			from .Cd import Cd
			self._cd = Cd(self._core, self._base)
		return self._cd

	@property
	def ce(self):
		"""ce commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ce'):
			from .Ce import Ce
			self._ce = Ce(self._core, self._base)
		return self._ce

	@property
	def cf(self):
		"""cf commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_cf'):
			from .Cf import Cf
			self._cf = Cf(self._core, self._base)
		return self._cf

	@property
	def cg(self):
		"""cg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_cg'):
			from .Cg import Cg
			self._cg = Cg(self._core, self._base)
		return self._cg

	@property
	def ch(self):
		"""ch commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ch'):
			from .Ch import Ch
			self._ch = Ch(self._core, self._base)
		return self._ch

	@property
	def de(self):
		"""de commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_de'):
			from .De import De
			self._de = De(self._core, self._base)
		return self._de

	@property
	def df(self):
		"""df commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_df'):
			from .Df import Df
			self._df = Df(self._core, self._base)
		return self._df

	@property
	def dg(self):
		"""dg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dg'):
			from .Dg import Dg
			self._dg = Dg(self._core, self._base)
		return self._dg

	@property
	def dh(self):
		"""dh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_dh'):
			from .Dh import Dh
			self._dh = Dh(self._core, self._base)
		return self._dh

	@property
	def ef(self):
		"""ef commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ef'):
			from .Ef import Ef
			self._ef = Ef(self._core, self._base)
		return self._ef

	@property
	def eg(self):
		"""eg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_eg'):
			from .Eg import Eg
			self._eg = Eg(self._core, self._base)
		return self._eg

	@property
	def eh(self):
		"""eh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_eh'):
			from .Eh import Eh
			self._eh = Eh(self._core, self._base)
		return self._eh

	@property
	def fg(self):
		"""fg commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_fg'):
			from .Fg import Fg
			self._fg = Fg(self._core, self._base)
		return self._fg

	@property
	def fh(self):
		"""fh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_fh'):
			from .Fh import Fh
			self._fh = Fh(self._core, self._base)
		return self._fh

	@property
	def gh(self):
		"""gh commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_gh'):
			from .Gh import Gh
			self._gh = Gh(self._core, self._base)
		return self._gh

	@property
	def row(self):
		"""row commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_row'):
			from .Row import Row
			self._row = Row(self._core, self._base)
		return self._row

	@property
	def ab(self):
		"""ab commands group. 4 Sub-classes, 0 commands."""
		if not hasattr(self, '_ab'):
			from .Ab import Ab
			self._ab = Ab(self._core, self._base)
		return self._ab

	def clone(self) -> 'Tx':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Tx(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class RoMode:
	"""RoMode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("roMode", core, parent)

	def set(self, ro_mode: enums.ReadOutMode, baseSt=repcap.BaseSt.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:BASE<ST>:LOCation:WAYPoints:ROMode \n
		Snippet: driver.source.bb.gnss.rtk.base.location.waypoints.roMode.set(ro_mode = enums.ReadOutMode.CYCLic, baseSt = repcap.BaseSt.Default) \n
		No command help available \n
			:param ro_mode: No help available
			:param baseSt: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Base')"""
		param = Conversions.enum_scalar_to_str(ro_mode, enums.ReadOutMode)
		baseSt_cmd_val = self._base.get_repcap_cmd_value(baseSt, repcap.BaseSt)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:RTK:BASE{baseSt_cmd_val}:LOCation:WAYPoints:ROMode {param}')

	# noinspection PyTypeChecker
	def get(self, baseSt=repcap.BaseSt.Default) -> enums.ReadOutMode:
		"""SCPI: [SOURce<HW>]:BB:GNSS:RTK:BASE<ST>:LOCation:WAYPoints:ROMode \n
		Snippet: value: enums.ReadOutMode = driver.source.bb.gnss.rtk.base.location.waypoints.roMode.get(baseSt = repcap.BaseSt.Default) \n
		No command help available \n
			:param baseSt: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Base')
			:return: ro_mode: No help available"""
		baseSt_cmd_val = self._base.get_repcap_cmd_value(baseSt, repcap.BaseSt)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:RTK:BASE{baseSt_cmd_val}:LOCation:WAYPoints:ROMode?')
		return Conversions.str_to_scalar_enum(response, enums.ReadOutMode)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal.RepeatedCapability import RepeatedCapability
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Alloc:
	"""Alloc commands group definition. 1 total commands, 1 Sub-groups, 0 group commands
	Repeated Capability: AllocationNull, default value after init: AllocationNull.Nr0"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("alloc", core, parent)
		self._base.rep_cap = RepeatedCapability(self._base.group_name, 'repcap_allocationNull_get', 'repcap_allocationNull_set', repcap.AllocationNull.Nr0)

	def repcap_allocationNull_set(self, enum_value: repcap.AllocationNull) -> None:
		"""Repeated Capability default value numeric suffix.
		This value is used, if you do not explicitely set it in the child set/get methods, or if you leave it to AllocationNull.Default
		Default value after init: AllocationNull.Nr0"""
		self._base.set_repcap_enum_value(enum_value)

	def repcap_allocationNull_get(self) -> repcap.AllocationNull:
		"""Returns the current default repeated capability for the child set/get methods"""
		# noinspection PyTypeChecker
		return self._base.get_repcap_enum_value()

	@property
	def pusch(self):
		"""pusch commands group. 1 Sub-classes, 0 commands."""
		if not hasattr(self, '_pusch'):
			from .Pusch import Pusch
			self._pusch = Pusch(self._core, self._base)
		return self._pusch

	def clone(self) -> 'Alloc':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Alloc(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .......Internal.Core import Core
from .......Internal.CommandsGroup import CommandsGroup
from .......Internal import Conversions
from ....... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, path=repcap.Path.Default, stream=repcap.Stream.Default) -> None:
		"""SCPI: SCONfiguration:OUTPut:MAPPing:RF<CH>:STReam<ST>:STATe \n
		Snippet: driver.sconfiguration.output.mapping.rf.stream.state.set(state = False, path = repcap.Path.Default, stream = repcap.Stream.Default) \n
		Maps the I/Q output streams to the output connectors. The stream mapping to the FADER connectors is fixed. \n
			:param state: 0| 1| OFF| ON
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')"""
		param = Conversions.bool_to_str(state)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		self._core.io.write(f'SCONfiguration:OUTPut:MAPPing:RF{path_cmd_val}:STReam{stream_cmd_val}:STATe {param}')

	def get(self, path=repcap.Path.Default, stream=repcap.Stream.Default) -> bool:
		"""SCPI: SCONfiguration:OUTPut:MAPPing:RF<CH>:STReam<ST>:STATe \n
		Snippet: value: bool = driver.sconfiguration.output.mapping.rf.stream.state.get(path = repcap.Path.Default, stream = repcap.Stream.Default) \n
		Maps the I/Q output streams to the output connectors. The stream mapping to the FADER connectors is fixed. \n
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Rf')
			:param stream: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Stream')
			:return: state: 0| 1| OFF| ON"""
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		stream_cmd_val = self._base.get_repcap_cmd_value(stream, repcap.Stream)
		response = self._core.io.query_str(f'SCONfiguration:OUTPut:MAPPing:RF{path_cmd_val}:STReam{stream_cmd_val}:STATe?')
		return Conversions.str_to_bool(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Power:
	"""Power commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("power", core, parent)

	def set(self, power: float, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:EMTC:TRANs<CH>:POWer \n
		Snippet: driver.source.bb.eutra.uplink.ue.emtc.trans.power.set(power = 1.0, userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		Sets the power of the eMTC PUSCH and PUCCH transmission \n
			:param power: float Range: -80 to 10
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')"""
		param = Conversions.decimal_value_to_str(power)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._base.get_repcap_cmd_value(transmission, repcap.Transmission)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:EMTC:TRANs{transmission_cmd_val}:POWer {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default, transmission=repcap.Transmission.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:EMTC:TRANs<CH>:POWer \n
		Snippet: value: float = driver.source.bb.eutra.uplink.ue.emtc.trans.power.get(userEquipment = repcap.UserEquipment.Default, transmission = repcap.Transmission.Default) \n
		Sets the power of the eMTC PUSCH and PUCCH transmission \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:param transmission: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Trans')
			:return: power: float Range: -80 to 10"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		transmission_cmd_val = self._base.get_repcap_cmd_value(transmission, repcap.Transmission)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:EMTC:TRANs{transmission_cmd_val}:POWer?')
		return Conversions.str_to_float(response)



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup
from ...........Internal import Conversions
from ........... import enums
from ........... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Select:
	"""Select commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("select", core, parent)

	def set(self, select: enums.GsmBursTsc, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:[SOURce]:TSC:SELect \n
		Snippet: driver.source.bb.gsm.frame.slot.subChannel.user.source.tsc.select.set(select = enums.GsmBursTsc.T0, frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		The command selects the training sequence code. The values specified in GSM 5.02 are T0...T7. When USER is selected, the
		value specified with the aid of the ...:TSC:USER command described next is used. \n
			:param select: T0| T1| T2| T3| T4| T5| T6| T7| USER
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.enum_scalar_to_str(select, enums.GsmBursTsc)
		frameIx_cmd_val = self._base.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._base.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._base.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:SOURce:TSC:SELect {param}')

	# noinspection PyTypeChecker
	def get(self, frameIx=repcap.FrameIx.Default, slotNull=repcap.SlotNull.Default, subchannel=repcap.Subchannel.Default, userIx=repcap.UserIx.Default) -> enums.GsmBursTsc:
		"""SCPI: [SOURce<HW>]:BB:GSM:[FRAMe<DI>]:SLOT<ST0>:[SUBChannel<US>]:[USER<CH>]:[SOURce]:TSC:SELect \n
		Snippet: value: enums.GsmBursTsc = driver.source.bb.gsm.frame.slot.subChannel.user.source.tsc.select.get(frameIx = repcap.FrameIx.Default, slotNull = repcap.SlotNull.Default, subchannel = repcap.Subchannel.Default, userIx = repcap.UserIx.Default) \n
		The command selects the training sequence code. The values specified in GSM 5.02 are T0...T7. When USER is selected, the
		value specified with the aid of the ...:TSC:USER command described next is used. \n
			:param frameIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Frame')
			:param slotNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Slot')
			:param subchannel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'SubChannel')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: select: T0| T1| T2| T3| T4| T5| T6| T7| USER"""
		frameIx_cmd_val = self._base.get_repcap_cmd_value(frameIx, repcap.FrameIx)
		slotNull_cmd_val = self._base.get_repcap_cmd_value(slotNull, repcap.SlotNull)
		subchannel_cmd_val = self._base.get_repcap_cmd_value(subchannel, repcap.Subchannel)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GSM:FRAMe{frameIx_cmd_val}:SLOT{slotNull_cmd_val}:SUBChannel{subchannel_cmd_val}:USER{userIx_cmd_val}:SOURce:TSC:SELect?')
		return Conversions.str_to_scalar_enum(response, enums.GsmBursTsc)



from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Obaseband:
	"""Obaseband commands group definition. 2 total commands, 0 Sub-groups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("obaseband", core, parent)

	def get_delay(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TRIGger:OBASeband:DELay \n
		Snippet: value: float = driver.source.bb.gnss.trigger.obaseband.get_delay() \n
		Specifies the trigger delay for triggering by the signal from the second path. \n
			:return: delay: float Range: 0 to 23.324365344
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TRIGger:OBASeband:DELay?')
		return Conversions.str_to_float(response)

	def set_delay(self, delay: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TRIGger:OBASeband:DELay \n
		Snippet: driver.source.bb.gnss.trigger.obaseband.set_delay(delay = 1.0) \n
		Specifies the trigger delay for triggering by the signal from the second path. \n
			:param delay: float Range: 0 to 23.324365344
		"""
		param = Conversions.decimal_value_to_str(delay)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TRIGger:OBASeband:DELay {param}')

	def get_inhibit(self) -> float:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TRIGger:OBASeband:INHibit \n
		Snippet: value: float = driver.source.bb.gnss.trigger.obaseband.get_inhibit() \n
		For triggering via the other path, specifies the number of samples by which a restart is inhibited. \n
			:return: inhibit: float Range: 0 to 0.728886406
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:BB:GNSS:TRIGger:OBASeband:INHibit?')
		return Conversions.str_to_float(response)

	def set_inhibit(self, inhibit: float) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:TRIGger:OBASeband:INHibit \n
		Snippet: driver.source.bb.gnss.trigger.obaseband.set_inhibit(inhibit = 1.0) \n
		For triggering via the other path, specifies the number of samples by which a restart is inhibited. \n
			:param inhibit: float Range: 0 to 0.728886406
		"""
		param = Conversions.decimal_value_to_str(inhibit)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:TRIGger:OBASeband:INHibit {param}')



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Nidcsi:
	"""Nidcsi commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("nidcsi", core, parent)

	def set(self, ca_ni_dcsi: int, cellNull=repcap.CellNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:CA:CELL<CH0>:NIDCsi \n
		Snippet: driver.source.bb.v5G.downlink.ca.cell.nidcsi.set(ca_ni_dcsi = 1, cellNull = repcap.CellNull.Default) \n
		Sets the scrambling identity NIDCSI used to generate the CSI-RS signal. \n
			:param ca_ni_dcsi: integer Range: 0 to 503
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')"""
		param = Conversions.decimal_value_to_str(ca_ni_dcsi)
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:V5G:DL:CA:CELL{cellNull_cmd_val}:NIDCsi {param}')

	def get(self, cellNull=repcap.CellNull.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:V5G:DL:CA:CELL<CH0>:NIDCsi \n
		Snippet: value: int = driver.source.bb.v5G.downlink.ca.cell.nidcsi.get(cellNull = repcap.CellNull.Default) \n
		Sets the scrambling identity NIDCSI used to generate the CSI-RS signal. \n
			:param cellNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Cell')
			:return: ca_ni_dcsi: integer Range: 0 to 503"""
		cellNull_cmd_val = self._base.get_repcap_cmd_value(cellNull, repcap.CellNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:V5G:DL:CA:CELL{cellNull_cmd_val}:NIDCsi?')
		return Conversions.str_to_int(response)



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Data:
	"""Data commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("data", core, parent)

	def set(self, data: enums.EutraDlDataSourceUser, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default, codeword=repcap.Codeword.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ALLoc<CH0>:[CW<USER>]:DATA \n
		Snippet: driver.source.bb.eutra.downlink.subf.alloc.cw.data.set(data = enums.EutraDlDataSourceUser.DLISt, subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default, codeword = repcap.Codeword.Default) \n
		Sets the data source for the selected allocation. For allocations with two codewords, the data source for the second
		codeword is automatically set to the data source set for the first one. \n
			:param data: USER1| USER2| USER3| USER4| PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE| MIB| MCCH| MTCH MIB (Result parameter) Indicates that the PBCH transmits real MIB data. (See also [:SOURcehw]:BB:EUTRa:DL:PBCH:MIB) MCCH|MTCH (Result parameter) Indicates allocations in the MBSFN subframes, if MBSFN is used. (See also [:SOURcehw]:BB:EUTRa:DL:MBSFn:MODE)
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param codeword: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cw')"""
		param = Conversions.enum_scalar_to_str(data, enums.EutraDlDataSourceUser)
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		codeword_cmd_val = self._base.get_repcap_cmd_value(codeword, repcap.Codeword)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CW{codeword_cmd_val}:DATA {param}')

	# noinspection PyTypeChecker
	def get(self, subframeNull=repcap.SubframeNull.Default, allocationNull=repcap.AllocationNull.Default, codeword=repcap.Codeword.Default) -> enums.EutraDlDataSourceUser:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:[SUBF<ST0>]:ALLoc<CH0>:[CW<USER>]:DATA \n
		Snippet: value: enums.EutraDlDataSourceUser = driver.source.bb.eutra.downlink.subf.alloc.cw.data.get(subframeNull = repcap.SubframeNull.Default, allocationNull = repcap.AllocationNull.Default, codeword = repcap.Codeword.Default) \n
		Sets the data source for the selected allocation. For allocations with two codewords, the data source for the second
		codeword is automatically set to the data source set for the first one. \n
			:param subframeNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Subf')
			:param allocationNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Alloc')
			:param codeword: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Cw')
			:return: data: USER1| USER2| USER3| USER4| PN9| PN11| PN15| PN16| PN20| PN21| PN23| PATTern| DLISt| ZERO| ONE| MIB| MCCH| MTCH MIB (Result parameter) Indicates that the PBCH transmits real MIB data. (See also [:SOURcehw]:BB:EUTRa:DL:PBCH:MIB) MCCH|MTCH (Result parameter) Indicates allocations in the MBSFN subframes, if MBSFN is used. (See also [:SOURcehw]:BB:EUTRa:DL:MBSFn:MODE)"""
		subframeNull_cmd_val = self._base.get_repcap_cmd_value(subframeNull, repcap.SubframeNull)
		allocationNull_cmd_val = self._base.get_repcap_cmd_value(allocationNull, repcap.AllocationNull)
		codeword_cmd_val = self._base.get_repcap_cmd_value(codeword, repcap.Codeword)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:SUBF{subframeNull_cmd_val}:ALLoc{allocationNull_cmd_val}:CW{codeword_cmd_val}:DATA?')
		return Conversions.str_to_scalar_enum(response, enums.EutraDlDataSourceUser)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Ppower:
	"""Ppower commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("ppower", core, parent)

	@property
	def step(self):
		"""step commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_step'):
			from .Step import Step
			self._step = Step(self._core, self._base)
		return self._step

	def set(self, ppower: float, mobileStation=repcap.MobileStation.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PCPCh:PPOWer \n
		Snippet: driver.source.bb.w3Gpp.mstation.pcpch.ppower.set(ppower = 1.0, mobileStation = repcap.MobileStation.Default) \n
		Sets the power of the preamble component of the PCPCH. If the preamble is repeated and the power increased with each
		repetition, this setting specifies the power achieved during the last repetition. \n
			:param ppower: float Range: -80 to 0
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')"""
		param = Conversions.decimal_value_to_str(ppower)
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PCPCh:PPOWer {param}')

	def get(self, mobileStation=repcap.MobileStation.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:MSTation<ST>:PCPCh:PPOWer \n
		Snippet: value: float = driver.source.bb.w3Gpp.mstation.pcpch.ppower.get(mobileStation = repcap.MobileStation.Default) \n
		Sets the power of the preamble component of the PCPCH. If the preamble is repeated and the power increased with each
		repetition, this setting specifies the power achieved during the last repetition. \n
			:param mobileStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Mstation')
			:return: ppower: float Range: -80 to 0"""
		mobileStation_cmd_val = self._base.get_repcap_cmd_value(mobileStation, repcap.MobileStation)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:MSTation{mobileStation_cmd_val}:PCPCh:PPOWer?')
		return Conversions.str_to_float(response)

	def clone(self) -> 'Ppower':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Ppower(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Vehicle:
	"""Vehicle commands group definition. 5 total commands, 2 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("vehicle", core, parent)

	@property
	def predefined(self):
		"""predefined commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_predefined'):
			from .Predefined import Predefined
			self._predefined = Predefined(self._core, self._base)
		return self._predefined

	@property
	def user(self):
		"""user commands group. 0 Sub-classes, 2 commands."""
		if not hasattr(self, '_user'):
			from .User import User
			self._user = User(self._core, self._base)
		return self._user

	# noinspection PyTypeChecker
	def get_mode(self) -> enums.FadDssUsrVehMode:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:VEHicle:MODE \n
		Snippet: value: enums.FadDssUsrVehMode = driver.source.fsimulator.dsSimulation.user.rx.vehicle.get_mode() \n
		No command help available \n
			:return: veh_mode: No help available
		"""
		response = self._core.io.query_str('SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:VEHicle:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.FadDssUsrVehMode)

	def set_mode(self, veh_mode: enums.FadDssUsrVehMode) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DSSimulation:USER:RX:VEHicle:MODE \n
		Snippet: driver.source.fsimulator.dsSimulation.user.rx.vehicle.set_mode(veh_mode = enums.FadDssUsrVehMode.NONE) \n
		No command help available \n
			:param veh_mode: No help available
		"""
		param = Conversions.enum_scalar_to_str(veh_mode, enums.FadDssUsrVehMode)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DSSimulation:USER:RX:VEHicle:MODE {param}')

	def clone(self) -> 'Vehicle':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Vehicle(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Dcatalog:
	"""Dcatalog commands group definition. 2 total commands, 1 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("dcatalog", core, parent)

	@property
	def length(self):
		"""length commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_length'):
			from .Length import Length
			self._length = Length(self._core, self._base)
		return self._length

	def get_value(self) -> str:
		"""SCPI: MMEMory:DCATalog \n
		Snippet: value: str = driver.massMemory.dcatalog.get_value() \n
		Returns the subdirectories of a particular directory. \n
			:return: dcatalog: No help available
		"""
		response = self._core.io.query_str('MMEMory:DCATalog?')
		return trim_str_response(response)

	def clone(self) -> 'Dcatalog':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Dcatalog(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ...........Internal.Core import Core
from ...........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class SeqElem:
	"""SeqElem commands group definition. 8 total commands, 8 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("seqElem", core, parent)

	@property
	def conflict(self):
		"""conflict commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_conflict'):
			from .Conflict import Conflict
			self._conflict = Conflict(self._core, self._base)
		return self._conflict

	@property
	def harq(self):
		"""harq commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_harq'):
			from .Harq import Harq
			self._harq = Harq(self._core, self._base)
		return self._harq

	@property
	def ndi(self):
		"""ndi commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ndi'):
			from .Ndi import Ndi
			self._ndi = Ndi(self._core, self._base)
		return self._ndi

	@property
	def ptpc(self):
		"""ptpc commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ptpc'):
			from .Ptpc import Ptpc
			self._ptpc = Ptpc(self._core, self._base)
		return self._ptpc

	@property
	def rba(self):
		"""rba commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rba'):
			from .Rba import Rba
			self._rba = Rba(self._core, self._base)
		return self._rba

	@property
	def rv(self):
		"""rv commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_rv'):
			from .Rv import Rv
			self._rv = Rv(self._core, self._base)
		return self._rv

	@property
	def subframe(self):
		"""subframe commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_subframe'):
			from .Subframe import Subframe
			self._subframe = Subframe(self._core, self._base)
		return self._subframe

	@property
	def ulIndex(self):
		"""ulIndex commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_ulIndex'):
			from .UlIndex import UlIndex
			self._ulIndex = UlIndex(self._core, self._base)
		return self._ulIndex

	def clone(self) -> 'SeqElem':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = SeqElem(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, satelliteSvid=repcap.SatelliteSvid.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:QZSS:SIGNal:L1Band:CA:[STATe] \n
		Snippet: driver.source.bb.gnss.svid.qzss.signal.l1Band.ca.state.set(state = False, satelliteSvid = repcap.SatelliteSvid.Default) \n
		Activates the selected signal. \n
			:param state: 0| 1| OFF| ON
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')"""
		param = Conversions.bool_to_str(state)
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:QZSS:SIGNal:L1Band:CA:STATe {param}')

	def get(self, satelliteSvid=repcap.SatelliteSvid.Default) -> bool:
		"""SCPI: [SOURce<HW>]:BB:GNSS:SVID<CH>:QZSS:SIGNal:L1Band:CA:[STATe] \n
		Snippet: value: bool = driver.source.bb.gnss.svid.qzss.signal.l1Band.ca.state.get(satelliteSvid = repcap.SatelliteSvid.Default) \n
		Activates the selected signal. \n
			:param satelliteSvid: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Svid')
			:return: state: 0| 1| OFF| ON"""
		satelliteSvid_cmd_val = self._base.get_repcap_cmd_value(satelliteSvid, repcap.SatelliteSvid)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:GNSS:SVID{satelliteSvid_cmd_val}:QZSS:SIGNal:L1Band:CA:STATe?')
		return Conversions.str_to_bool(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Increment:
	"""Increment commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("increment", core, parent)

	def set(self, increment: int, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:SCONtrol:FRAGment:INCRement \n
		Snippet: driver.source.bb.wlnn.fblock.user.mac.scontrol.fragment.increment.set(increment = 1, frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Defines the number of packets required to increment the counter of the fragment bits of the sequence control. \n
			:param increment: integer Range: 0 to 1024
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.decimal_value_to_str(increment)
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		self._core.io.write(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:SCONtrol:FRAGment:INCRement {param}')

	def get(self, frameBlock=repcap.FrameBlock.Default, userIx=repcap.UserIx.Default) -> int:
		"""SCPI: [SOURce<HW>]:BB:WLNN:FBLock<CH>:[USER<DI>]:MAC:SCONtrol:FRAGment:INCRement \n
		Snippet: value: int = driver.source.bb.wlnn.fblock.user.mac.scontrol.fragment.increment.get(frameBlock = repcap.FrameBlock.Default, userIx = repcap.UserIx.Default) \n
		Defines the number of packets required to increment the counter of the fragment bits of the sequence control. \n
			:param frameBlock: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Fblock')
			:param userIx: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: increment: integer Range: 0 to 1024"""
		frameBlock_cmd_val = self._base.get_repcap_cmd_value(frameBlock, repcap.FrameBlock)
		userIx_cmd_val = self._base.get_repcap_cmd_value(userIx, repcap.UserIx)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:WLNN:FBLock{frameBlock_cmd_val}:USER{userIx_cmd_val}:MAC:SCONtrol:FRAGment:INCRement?')
		return Conversions.str_to_int(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Via:
	"""Via commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("via", core, parent)

	def set(self, via: enums.IqOutDispViaType, iqConnector=repcap.IqConnector.Default) -> None:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:POWer:VIA \n
		Snippet: driver.source.iq.output.digital.bbmm.power.via.set(via = enums.IqOutDispViaType.LEVel, iqConnector = repcap.IqConnector.Default) \n
		No command help available \n
			:param via: PEP| LEVel
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')"""
		param = Conversions.enum_scalar_to_str(via, enums.IqOutDispViaType)
		iqConnector_cmd_val = self._base.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		self._core.io.write(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:POWer:VIA {param}')

	# noinspection PyTypeChecker
	def get(self, iqConnector=repcap.IqConnector.Default) -> enums.IqOutDispViaType:
		"""SCPI: [SOURce]:IQ:OUTPut:DIGital:BBMM<CH>:POWer:VIA \n
		Snippet: value: enums.IqOutDispViaType = driver.source.iq.output.digital.bbmm.power.via.get(iqConnector = repcap.IqConnector.Default) \n
		No command help available \n
			:param iqConnector: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bbmm')
			:return: via: PEP| LEVel"""
		iqConnector_cmd_val = self._base.get_repcap_cmd_value(iqConnector, repcap.IqConnector)
		response = self._core.io.query_str(f'SOURce:IQ:OUTPut:DIGital:BBMM{iqConnector_cmd_val}:POWer:VIA?')
		return Conversions.str_to_scalar_enum(response, enums.IqOutDispViaType)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Prach:
	"""Prach commands group definition. 12 total commands, 5 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("prach", core, parent)

	@property
	def cframes(self):
		"""cframes commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_cframes'):
			from .Cframes import Cframes
			self._cframes = Cframes(self._core, self._base)
		return self._cframes

	@property
	def prFormat(self):
		"""prFormat commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prFormat'):
			from .PrFormat import PrFormat
			self._prFormat = PrFormat(self._core, self._base)
		return self._prFormat

	@property
	def prState(self):
		"""prState commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prState'):
			from .PrState import PrState
			self._prState = PrState(self._core, self._base)
		return self._prState

	@property
	def prtt(self):
		"""prtt commands group. 0 Sub-classes, 1 commands."""
		if not hasattr(self, '_prtt'):
			from .Prtt import Prtt
			self._prtt = Prtt(self._core, self._base)
		return self._prtt

	@property
	def subf(self):
		"""subf commands group. 8 Sub-classes, 0 commands."""
		if not hasattr(self, '_subf'):
			from .Subf import Subf
			self._subf = Subf(self._core, self._base)
		return self._subf

	def clone(self) -> 'Prach':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Prach(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import enums
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Tsource:
	"""Tsource commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("tsource", core, parent)

	def set(self, tsource: enums.TetraTscSource, testMode=repcap.TestMode.Default, slot=repcap.Slot.Default, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SCONfiguration:TMODe<DI>:SLOT<ST>:LDIRection<CH>:TSOurce \n
		Snippet: driver.source.bb.tetra.sconfiguration.tmode.slot.ldirection.tsource.set(tsource = enums.TetraTscSource.DEFault, testMode = repcap.TestMode.Default, slot = repcap.Slot.Default, channel = repcap.Channel.Default) \n
		Determines whether the default or a user-defined training sequence (TSC) is used. A user-defined training sequence can be
		created in the field 'TSC User Defined'. \n
			:param tsource: DEFault| UDEFined
			:param testMode: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tmode')
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slot')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ldirection')"""
		param = Conversions.enum_scalar_to_str(tsource, enums.TetraTscSource)
		testMode_cmd_val = self._base.get_repcap_cmd_value(testMode, repcap.TestMode)
		slot_cmd_val = self._base.get_repcap_cmd_value(slot, repcap.Slot)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:TETRa:SCONfiguration:TMODe{testMode_cmd_val}:SLOT{slot_cmd_val}:LDIRection{channel_cmd_val}:TSOurce {param}')

	# noinspection PyTypeChecker
	def get(self, testMode=repcap.TestMode.Default, slot=repcap.Slot.Default, channel=repcap.Channel.Default) -> enums.TetraTscSource:
		"""SCPI: [SOURce<HW>]:BB:TETRa:SCONfiguration:TMODe<DI>:SLOT<ST>:LDIRection<CH>:TSOurce \n
		Snippet: value: enums.TetraTscSource = driver.source.bb.tetra.sconfiguration.tmode.slot.ldirection.tsource.get(testMode = repcap.TestMode.Default, slot = repcap.Slot.Default, channel = repcap.Channel.Default) \n
		Determines whether the default or a user-defined training sequence (TSC) is used. A user-defined training sequence can be
		created in the field 'TSC User Defined'. \n
			:param testMode: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Tmode')
			:param slot: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Slot')
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ldirection')
			:return: tsource: DEFault| UDEFined"""
		testMode_cmd_val = self._base.get_repcap_cmd_value(testMode, repcap.TestMode)
		slot_cmd_val = self._base.get_repcap_cmd_value(slot, repcap.Slot)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:TETRa:SCONfiguration:TMODe{testMode_cmd_val}:SLOT{slot_cmd_val}:LDIRection{channel_cmd_val}:TSOurce?')
		return Conversions.str_to_scalar_enum(response, enums.TetraTscSource)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Correlation:
	"""Correlation commands group definition. 232 total commands, 2 Sub-groups, 0 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("correlation", core, parent)

	@property
	def rx(self):
		"""rx commands group. 29 Sub-classes, 0 commands."""
		if not hasattr(self, '_rx'):
			from .Rx import Rx
			self._rx = Rx(self._core, self._base)
		return self._rx

	@property
	def tx(self):
		"""tx commands group. 29 Sub-classes, 0 commands."""
		if not hasattr(self, '_tx'):
			from .Tx import Tx
			self._tx = Tx(self._core, self._base)
		return self._tx

	def clone(self) -> 'Correlation':
		"""Clones the group by creating new object from it and its whole existing sub-groups
		Also copies all the existing default Repeated Capabilities setting,
		which you can change independently without affecting the original group"""
		new_group = Correlation(self._core, self._base.parent)
		self._base.synchronize_repcaps(new_group)
		return new_group



from typing import List

from .........Internal.Core import Core
from .........Internal.CommandsGroup import CommandsGroup
from .........Internal import Conversions
from ......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class TrptSubset:
	"""TrptSubset commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("trptSubset", core, parent)

	def set(self, trpt_subset: List[str], userEquipment=repcap.UserEquipment.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:RDATa:TRPTsubset \n
		Snippet: driver.source.bb.eutra.uplink.ue.sl.rdata.trptSubset.set(trpt_subset = ['raw1', 'raw2', 'raw3'], userEquipment = repcap.UserEquipment.Default) \n
		The TRTP subset is a time resources pattern that indicates the set of available subframes to be used for sidelink
		communication. \n
			:param trpt_subset: 5 bits
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')"""
		param = Conversions.list_to_csv_str(trpt_subset)
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:RDATa:TRPTsubset {param}')

	def get(self, userEquipment=repcap.UserEquipment.Default) -> List[str]:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:UL:UE<ST>:SL:RDATa:TRPTsubset \n
		Snippet: value: List[str] = driver.source.bb.eutra.uplink.ue.sl.rdata.trptSubset.get(userEquipment = repcap.UserEquipment.Default) \n
		The TRTP subset is a time resources pattern that indicates the set of available subframes to be used for sidelink
		communication. \n
			:param userEquipment: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Ue')
			:return: trpt_subset: 5 bits"""
		userEquipment_cmd_val = self._base.get_repcap_cmd_value(userEquipment, repcap.UserEquipment)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:UL:UE{userEquipment_cmd_val}:SL:RDATa:TRPTsubset?')
		return Conversions.str_to_str_list(response)



from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class State:
	"""State commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("state", core, parent)

	def set(self, state: bool, fadingGroup=repcap.FadingGroup.Default, path=repcap.Path.Default) -> None:
		"""SCPI: [SOURce<HW>]:FSIMulator:DELay:GROup<ST>:PATH<CH>:CORRelation:STATe \n
		Snippet: driver.source.fsimulator.delay.group.path.correlation.state.set(state = False, fadingGroup = repcap.FadingGroup.Default, path = repcap.Path.Default) \n
		Enables correlation of the paths of the first fader. The suffix in SOURce defines the fader on which path settings the
		correlation is based. When correlation is activated, the settings of the correlation parameters, the profile, the speed
		and the lognormal parameters are the same for both paths. \n
			:param state: 0| 1| OFF| ON
			:param fadingGroup: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Group')
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')"""
		param = Conversions.bool_to_str(state)
		fadingGroup_cmd_val = self._base.get_repcap_cmd_value(fadingGroup, repcap.FadingGroup)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		self._core.io.write(f'SOURce<HwInstance>:FSIMulator:DELay:GROup{fadingGroup_cmd_val}:PATH{path_cmd_val}:CORRelation:STATe {param}')

	def get(self, fadingGroup=repcap.FadingGroup.Default, path=repcap.Path.Default) -> bool:
		"""SCPI: [SOURce<HW>]:FSIMulator:DELay:GROup<ST>:PATH<CH>:CORRelation:STATe \n
		Snippet: value: bool = driver.source.fsimulator.delay.group.path.correlation.state.get(fadingGroup = repcap.FadingGroup.Default, path = repcap.Path.Default) \n
		Enables correlation of the paths of the first fader. The suffix in SOURce defines the fader on which path settings the
		correlation is based. When correlation is activated, the settings of the correlation parameters, the profile, the speed
		and the lognormal parameters are the same for both paths. \n
			:param fadingGroup: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Group')
			:param path: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Path')
			:return: state: 0| 1| OFF| ON"""
		fadingGroup_cmd_val = self._base.get_repcap_cmd_value(fadingGroup, repcap.FadingGroup)
		path_cmd_val = self._base.get_repcap_cmd_value(path, repcap.Path)
		response = self._core.io.query_str(f'SOURce<HwInstance>:FSIMulator:DELay:GROup{fadingGroup_cmd_val}:PATH{path_cmd_val}:CORRelation:STATe?')
		return Conversions.str_to_bool(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions
from .......... import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Pstep:
	"""Pstep commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("pstep", core, parent)

	def set(self, pstep: float, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:FDPCh:DPCCh:TPC:PSTep \n
		Snippet: driver.source.bb.w3Gpp.bstation.channel.fdpch.dpcch.tpc.pstep.set(pstep = 1.0, baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command defines the step width for the change of channel powers in the case of 'mis-' use of the TPC field. \n
			:param pstep: float Range: -10.0 dB to 10.0 dB
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')"""
		param = Conversions.decimal_value_to_str(pstep)
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		self._core.io.write(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:FDPCh:DPCCh:TPC:PSTep {param}')

	def get(self, baseStation=repcap.BaseStation.Default, channelNull=repcap.ChannelNull.Default) -> float:
		"""SCPI: [SOURce<HW>]:BB:W3GPp:BSTation<ST>:CHANnel<CH0>:FDPCh:DPCCh:TPC:PSTep \n
		Snippet: value: float = driver.source.bb.w3Gpp.bstation.channel.fdpch.dpcch.tpc.pstep.get(baseStation = repcap.BaseStation.Default, channelNull = repcap.ChannelNull.Default) \n
		The command defines the step width for the change of channel powers in the case of 'mis-' use of the TPC field. \n
			:param baseStation: optional repeated capability selector. Default value: Nr1 (settable in the interface 'Bstation')
			:param channelNull: optional repeated capability selector. Default value: Nr0 (settable in the interface 'Channel')
			:return: pstep: float Range: -10.0 dB to 10.0 dB"""
		baseStation_cmd_val = self._base.get_repcap_cmd_value(baseStation, repcap.BaseStation)
		channelNull_cmd_val = self._base.get_repcap_cmd_value(channelNull, repcap.ChannelNull)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:W3GPp:BSTation{baseStation_cmd_val}:CHANnel{channelNull_cmd_val}:FDPCh:DPCCh:TPC:PSTep?')
		return Conversions.str_to_float(response)



from ..........Internal.Core import Core
from ..........Internal.CommandsGroup import CommandsGroup
from ..........Internal import Conversions


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class File:
	"""File commands group definition. 3 total commands, 0 Sub-groups, 3 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("file", core, parent)

	def set_ems(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:IMPort:ADD:FILE:EMS \n
		Snippet: driver.source.bb.gnss.atmospheric.ionospheric.mops.importPy.add.file.set_ems(filename = '1') \n
		Add *.ems, *.nstb or *.iono_grid files to an import file list. \n
			:param filename: string The Filename string comprises the file directory, filename and extension. For more information about *.ems and *.nstb files, see'SBAS correction file download links' . *.iono_grid files, see Example 'Ionospheric grid file content (extract) '.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:IMPort:ADD:FILE:EMS {param}')

	def set_grid(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:IMPort:ADD:FILE:GRID \n
		Snippet: driver.source.bb.gnss.atmospheric.ionospheric.mops.importPy.add.file.set_grid(filename = '1') \n
		Add *.ems, *.nstb or *.iono_grid files to an import file list. \n
			:param filename: string The Filename string comprises the file directory, filename and extension. For more information about *.ems and *.nstb files, see'SBAS correction file download links' . *.iono_grid files, see Example 'Ionospheric grid file content (extract) '.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:IMPort:ADD:FILE:GRID {param}')

	def set_nstb(self, filename: str) -> None:
		"""SCPI: [SOURce<HW>]:BB:GNSS:ATMospheric:IONospheric:MOPS:IMPort:ADD:FILE:NSTB \n
		Snippet: driver.source.bb.gnss.atmospheric.ionospheric.mops.importPy.add.file.set_nstb(filename = '1') \n
		Add *.ems, *.nstb or *.iono_grid files to an import file list. \n
			:param filename: string The Filename string comprises the file directory, filename and extension. For more information about *.ems and *.nstb files, see'SBAS correction file download links' . *.iono_grid files, see Example 'Ionospheric grid file content (extract) '.
		"""
		param = Conversions.value_to_quoted_str(filename)
		self._core.io.write(f'SOURce<HwInstance>:BB:GNSS:ATMospheric:IONospheric:MOPS:IMPort:ADD:FILE:NSTB {param}')
